"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SwfOffsetsApi = void 0;
var jsonata = require("jsonata");
var SwfOffsetsApi = (function () {
    function SwfOffsetsApi(astTransformQuery, documentUri) {
        if (documentUri === void 0) { documentUri = ""; }
        this.astTransformQuery = astTransformQuery;
        this.documentUri = documentUri;
    }
    SwfOffsetsApi.prototype.parseContent = function (fullText) {
        if (!fullText) {
            this.fullText = "";
            this.fullTextOffsets = undefined;
            return this;
        }
        if (this.fullText === fullText) {
            return this;
        }
        this.fullText = fullText;
        this.fullTextOffsets = this.getAllOffsets();
        return this;
    };
    SwfOffsetsApi.prototype.getAllOffsets = function () {
        if (!this.fullText) {
            return { states: {} };
        }
        var fullAST = this.getFullAST();
        if (!fullAST) {
            return { states: {} };
        }
        try {
            return jsonata(this.astTransformQuery).evaluate(fullAST);
        }
        catch (e) {
            return { states: {} };
        }
    };
    SwfOffsetsApi.prototype.getStateNameOffset = function (stateName) {
        var _a, _b;
        if (!stateName) {
            return undefined;
        }
        return ((_b = (_a = this.fullTextOffsets) === null || _a === void 0 ? void 0 : _a.states[stateName]) === null || _b === void 0 ? void 0 : _b.stateNameOffset) || undefined;
    };
    SwfOffsetsApi.prototype.getStateNameFromOffset = function (offset) {
        var _a;
        if (!offset) {
            return null;
        }
        for (var stateName in (_a = this.fullTextOffsets) === null || _a === void 0 ? void 0 : _a.states) {
            var blockOffset = this.fullTextOffsets.states[stateName].offset;
            if (offset >= blockOffset.start && offset <= blockOffset.end) {
                return stateName;
            }
        }
        return null;
    };
    return SwfOffsetsApi;
}());
exports.SwfOffsetsApi = SwfOffsetsApi;
//# sourceMappingURL=SwfOffsetsApi.js.map