import { CodeLens, CompletionItem, Position, Range } from "vscode-languageserver-types";
import { SwfServiceCatalogService } from "@kie-tools/serverless-workflow-service-catalog/dist/api";
import { FileLanguage, SwfLanguageServiceCommandExecution } from "../api";
import { TextDocument } from "vscode-json-languageservice";
import { SwfJsonPath, SwfLsNode, CodeCompletionStrategy } from "./types";
export declare type SwfLanguageServiceConfig = {
    shouldConfigureServiceRegistries: () => boolean;
    shouldServiceRegistriesLogIn: () => boolean;
    canRefreshServices: () => boolean;
    getSpecsDirPosixPaths: (textDocument: TextDocument) => Promise<{
        specsDirRelativePosixPath: string;
        specsDirAbsolutePosixPath: string;
    }>;
    shouldDisplayServiceRegistriesIntegration: () => Promise<boolean>;
    shouldReferenceServiceRegistryFunctionsWithUrls: () => Promise<boolean>;
    shouldIncludeJsonSchemaDiagnostics: () => Promise<boolean>;
};
export declare type SwfLanguageServiceArgs = {
    fs: {};
    lang: {
        fileLanguage: FileLanguage;
        fileMatch: string[];
    };
    serviceCatalog: {
        global: {
            getServices: () => Promise<SwfServiceCatalogService[]>;
        };
        relative: {
            getServices: (textDocument: TextDocument) => Promise<SwfServiceCatalogService[]>;
        };
        getServiceFileNameFromSwfServiceCatalogServiceId: (registryName: string, swfServiceCatalogServiceId: string) => Promise<string>;
    };
    config: SwfLanguageServiceConfig;
};
export declare class SwfLanguageService {
    private readonly args;
    constructor(args: SwfLanguageServiceArgs);
    getCompletionItems(args: {
        content: string;
        uri: string;
        cursorPosition: Position;
        cursorWordRange: Range;
        rootNode: SwfLsNode | undefined;
        codeCompletionStrategy: CodeCompletionStrategy;
    }): Promise<CompletionItem[]>;
    getDiagnostics(args: {
        content: string;
        uriPath: string;
        rootNode: SwfLsNode | undefined;
    }): Promise<import("vscode-languageserver-types").Diagnostic[]>;
    private getJsonSchemaDiagnostics;
    getCodeLenses(args: {
        content: string;
        uri: string;
        rootNode: SwfLsNode | undefined;
    }): Promise<CodeLens[]>;
    dispose(): void;
    private getSwfCompletionItemServiceCatalogFunctionOperation;
    createCodeLenses(args: {
        document: TextDocument;
        rootNode: SwfLsNode;
        jsonPath: SwfJsonPath;
        commandDelegates: (args: {
            position: Position;
            node: SwfLsNode;
        }) => ({
            title: string;
        } & SwfLanguageServiceCommandExecution<any>)[];
        positionLensAt: "begin" | "end";
    }): CodeLens[];
}
export declare function findNodeAtLocation(root: SwfLsNode, path: SwfJsonPath): SwfLsNode | undefined;
export declare function findNodeAtOffset(root: SwfLsNode, offset: number, includeRightBound?: boolean): SwfLsNode | undefined;
//# sourceMappingURL=SwfLanguageService.d.ts.map